#
# spec file for package libXaw3d
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libXaw3d
Version:        1.6.5
Release:        1.2
Summary:        The 3D Athena Widget Set
License:        MIT
Group:          Development/Libraries/C and C++
URL:            https://xorg.freedesktop.org/
#Git-Clone:	git://anongit.freedesktop.org/xorg/lib/libXaw3d
#Git-Web:	https://cgit.freedesktop.org/xorg/lib/libXaw3d/
Source:         https://xorg.freedesktop.org/releases/individual/lib/%name-%version.tar.xz
Source1:        https://xorg.freedesktop.org/releases/individual/lib/%name-%version.tar.xz.sig
Source2:        README.SuSE
Source3:        baselibs.conf
Source9:        libXaw3d.keyring
Patch1:         xaw3d-secure.patch
Patch2:         xaw3d-thumb.patch
Patch3:         xaw3d-hsbar.patch
Patch4:         xaw3d-3dlabel.patch
Patch5:         xaw3d-fontset.patch
Patch6:         xaw3d-elf.patch
Patch7:         xaw3d.patch
BuildRequires:  autoconf >= 2.60
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xpm)
BuildRequires:  pkgconfig(xt)

%description
Xaw3d is a general-purpose replacement for the Athena toolkit which
adds a 3D appearance and support for XPM images.

This is a library that can be used instead of the standard
Athena Widget Library. It has tried to keep the standard of the
libXaw library. There are also programs which explicitly use this
library (this is the reason why the library was included).

NOTE: Do NOT replace /usr/lib/libXaw.so.6.1!

%package -n libXaw3d6
Summary:        The 3D Athena Widget Set
Group:          System/Libraries

%description -n libXaw3d6
Xaw3d is a general-purpose replacement for the Athena toolkit which
adds a 3D appearance and support for XPM images.

%package -n libXaw3d7
Summary:        The 3D Athena Widget Set
Group:          System/Libraries

%description -n libXaw3d7
Xaw3d is a general-purpose replacement for the Athena toolkit which
adds a 3D appearance and support for XPM images.

%package -n libXaw3d8
Summary:        The 3D Athena Widget Set
Group:          System/Libraries
Provides:       Xaw3d = %version-%release
# bug437293
%ifarch ppc64
Obsoletes:      xaw3d-64bit
%endif
# Added for 13.1
Obsoletes:      xaw3d < %version-%release
Provides:       xaw3d = %version-%release

%description -n libXaw3d8
Xaw3d is a general-purpose replacement for the Athena toolkit which
adds a 3D appearance and support for XPM images.

%package devel
Summary:        Development files for the X Athena Widget Set
Group:          Development/Libraries/C and C++
Requires:       libXaw3d6 = %version
Requires:       libXaw3d7 = %version
Requires:       libXaw3d8 = %version
Provides:       xaw3d:/usr/include/X11/Xaw3d/Xaw3dP.h
# bug437293
%ifarch ppc64
Obsoletes:      xaw3d-devel-64bit
%endif
# O/P added for 13.2
Provides:       xaw3d-devel = %version-%release
Obsoletes:      xaw3d-devel < %version-%release

%description devel
Xaw3d is a general-purpose replacement for the Athena toolkit which
adds a 3D appearance and support for XPM images.

This package contains the development headers for the library found
in libXaw3d6/libXaw3d7/libXaw3d8.

%package -n xaw3dd
Summary:        Select 3D Athena Widgets as a replacement for Athena Widgets
Group:          System/Libraries
Requires:       libXaw3d6 = %version
Requires:       libXaw3d7 = %version
Requires:       libXaw3d8 = %version

%description -n xaw3dd
Installation of this package will cause programs utilizing the Athena
Widget Toolkit to instead use the 3D Athena Widget set.

If any problems arise using or starting X Window System programs,
remove this package.

%prep
%autosetup -p1

%build
autoreconf -fi
%configure --docdir=%_docdir/%name --disable-static	\
	--enable-internationalization			\
	--enable-multiplane-bitmaps			\
	--enable-gray-stipples				\
	--enable-arrow-scrollbars			\
	--with-gnu-ld					\

%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -print -delete

# Copy README here and then gobble it up via %%doc
mkdir -p %{buildroot}%_docdir/xaw3dd
cp %_sourcedir/README.SuSE %{buildroot}/%_docdir/xaw3dd/README.SUSE
ln -s %_docdir/xaw3dd/README.SUSE %{buildroot}%_libdir/Xaw3d/NOTE

# Create /etc/ld.so.conf.d/xaw3dd.conf
mkdir -p %{buildroot}%_sysconfdir/ld.so.conf.d
echo %_libdir/Xaw3d > %{buildroot}%_sysconfdir/ld.so.conf.d/xaw3dd.conf

%post   -n libXaw3d6 -p /sbin/ldconfig
%postun -n libXaw3d6 -p /sbin/ldconfig
%post   -n libXaw3d7 -p /sbin/ldconfig
%postun -n libXaw3d7 -p /sbin/ldconfig
%post   -n libXaw3d8 -p /sbin/ldconfig
%postun -n libXaw3d8 -p /sbin/ldconfig
%post   -n xaw3dd -p /sbin/ldconfig
%postun -n xaw3dd -p /sbin/ldconfig

%files -n libXaw3d6
%_libdir/libXaw3d.so.6*

%files -n libXaw3d7
%_libdir/libXaw3d.so.7*

%files -n libXaw3d8
%_libdir/libXaw3d.so.8*

%files devel
%_includedir/X11/Xaw3d/
%_libdir/libXaw3d.so
%_libdir/pkgconfig/xaw3d.pc
%_docdir/%name/

%files -n xaw3dd
%config %_sysconfdir/ld.so.conf.d/xaw3dd.conf
%_libdir/Xaw3d/
%doc %_libdir/Xaw3d/NOTE
%_docdir/xaw3dd/

%changelog
* Wed Aug 16 2023 Dr. Werner Fink <werner@suse.de>
- Update to libXaw3d 1.6.5:
  * Set close-on-exec when opening files
  * configure: pass noyywrap to AC_PROG_LEX if using autoconf 2.70 or later
  * Raises minimum autoconf version from 2.60 to 2.64 for m4_version_prereq
  * Clears autoconf warning:
    configure.ac:29: warning: AC_PROG_LEX without either yywrap or noyywrap is obsolete
    ./lib/autoconf/programs.m4:716: _AC_PROG_LEX is expanded from...
    ./lib/autoconf/programs.m4:709: AC_PROG_LEX is expanded from...
    configure.ac:29: the top level
  * configure: Use LT_INIT from libtool 2 instead of deprecated AC_PROG_LIBTOOL
  * AC_PROG_LIBTOOL was replaced by LT_INIT in libtool 2 in 2008,
    so it's time to rely on it.
  * Clears autoconf warnings:
    configure.ac:13: warning: The macro `AC_PROG_LIBTOOL' is obsolete.
    configure.ac:13: You should run autoupdate.
    aclocal.m4:3465: AC_PROG_LIBTOOL is expanded from...
    configure.ac:13: the top level
  * libtoolize: Consider adding 'AC_CONFIG_MACRO_DIRS([m4])' to configure.ac,
    libtoolize: and rerunning libtoolize and aclocal.
  * Issue #5: incompatible function pointer passed in _XawImRealize()
  * Import wrapper function with expected arguments from libXaw,
    where it appears to have been originally fixed in XFree86 3.9Nb
    by Paulo Cesar Pereira de Andrade.
- Port patch xaw3d-secure.patch
* Tue Sep 13 2022 Dr. Werner Fink <werner@suse.de>
- Move https to https even for URLs in comments
- Drop not existing URL
* Mon Aug 29 2022 Dirk Müller <dmueller@suse.com>
- update to 1.6.4:
  * convert ISO8859-1 encoded source files to UTF-8
  * Fix spelling/wording issues
  * Build xz tarballs instead of bzip2
  * fix configure doesn't fail if flex is not installed
  * build-fixes when _CONST_X_STRING is defined
  * Pass correct number of atoms from SelectSave to _XawTextSaltAwaySelection
  * Fix fd leak when write() fails in WriteToFile()
  * Bug 24635: File Descriptor leaks in libxaw-1.0.7
- add keyring and signature validation
* Fri Jun 18 2021 Jan Engelhardt <jengelh@inai.de>
- Drop --with-pic (no effect with --disable-static)
- Trim old rpm macros/constructs
* Tue Jun 19 2018 werner@suse.de
- Update to new upstream release 1.6.3
  * Avoid using dead pointer in _XawTextSetSelection
  * Fix copied from 2D libXaw commit 11c3a104141e1a4946ad949dfb5514df0b66a031
  * autogen: add default patch prefix
  * autogen.sh: use quoted string variables
  * Place quotes around the $srcdir, $ORIGDIR and $0 variables to prevent
    fall-outs, when they contain space.
  * autogen.sh: use exec instead of waiting for configure to finish
  * Syncs the invocation of configure with the one from the server.
  * darwin: Remove incorrect export of vendorShellClassRec and vendorShellWidgetClass
  * Get rid of some extraneous ; at the end of C source lines
  * Use SEEK_* names instead of raw numbers for fseek whence argument
  * Just use C89 size_t instead of rolling our own Size_t & Off_t
  * Fix abs() usage.
  * For long arguments, use labs().
  * autogen.sh: Honor NOCONFIGURE=1
  * configure: Drop AM_MAINTAINER_MODE
  * Remove support for pre-C89 headers (unifdef -UX_NOT_STDC_ENV)
  * Replace TXT16 with XChar2b inline
  * No longer need #define to substitute it now that we no longer set
    it to a different type on CRAY systems.
  * Remove CRAY/WORD64 support (unifdef -UCRAY -UWORD64)
  * Fix --disable-feature options in configure
  * Make --disable-feature options passed to configure not enable
    the feature but keep it disabled instead.
- Port our patches to new version
* Wed Oct  1 2014 crrodriguez@opensuse.org
- Ensure all "la" files are deleted, not just those in libdir
- Enable verbose build
- Do not use xorg-x11-devel
* Wed Aug 27 2014 fcrozat@suse.com
- Add baselibs.conf as source.
* Mon Aug 18 2014 fcrozat@suse.com
- Add obsoletes to baselibs.conf.
* Tue Nov 26 2013 jengelh@inai.de
- Add obsoletes/provides xaw3d-devel because we are now
  libXaw3d-devel
* Fri Nov 22 2013 jengelh@inai.de
- Redo xaw3d-elf.patch to modify Makefile.am instead and to also
  include description
- Remove hackish Provides: from .spec file that were only
  for use with symlinks
* Wed Oct 30 2013 werner@suse.de
- Follow crackbrained policy and change SuSE into SUSE
* Tue Oct 29 2013 werner@suse.de
- Make the libraries ELF compatible that is that each library has
  its own soname as otherwise the runtime linker may show warnings
- Enable the configure options for internationalization,
  multiplane-bitmaps, gray-stipples, and arrow-scrollbars
* Fri Jun 14 2013 jengelh@inai.de
- Rename xaw3d to libXaw3d. Use libXaw.spec and xaw3d.changes as base.
- Kill unused Conflicts: axe
- Update to new upstream release 1.6.2 (update from prior 1.5E
  released on 2003-04-17)
  * Nuke unused source code, resolve many compile warnings,
  switch to autotools
- Drop Xaw3d-1.5E-compat.patch, Xaw3d-1.5E-gvI18N.patch,
  Xaw3d-1.5E-null.patch, Xaw3d-1.5E-close-destroy-crash.patch
  (merged upstream).
- Drop Xaw3d-1.5E-cast.patch (resolved differently upstream).
- Rebased and renamed remaining patches from Xaw3d-1.5E-* to xaw3d-*
* Tue Aug  9 2011 werner@suse.de
- Correct path of latest change as .conf is required
* Mon Jul  4 2011 aj@suse.de
- Add /etc/ld.so.conf.d/xaw3dd for ldconfig (bnc#671725).
* Tue Aug 10 2010 werner@suse.de
- Add missing Xaw.so.7 version of Xaw3d (bnc#627314)
* Thu Dec 17 2009 jengelh@medozas.de
- add baselbis.conf as a source
- enable parallel building
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Fri Apr 17 2009 crrodriguez@suse.de
- remove static libraries
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Mon Nov  3 2008 schwab@suse.de
- Fix broken cast.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Jun 20 2007 dmueller@suse.de
- fix crash on exit due access to free'ed memory
* Tue May 29 2007 werner@suse.de
- Branch off xaw3d-devel to make RPMlint happy
* Thu Mar 29 2007 coolo@suse.de
- BuildRequire bison and flex
* Wed Sep 13 2006 werner@suse.de
- Add compatibility libs for binary only programs (bug #205169)
* Tue Sep 12 2006 schwab@suse.de
- Fix soname of overriding libraries [#205169].
* Wed Aug 16 2006 aj@suse.de
- Remove unneeded BuildRequires on xorg-x11.
* Fri Jul 28 2006 werner@suse.de
- Make it build with X11R7
* Mon Feb 27 2006 schwab@suse.de
- Run ldconfig also in xaw3dd package.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Nov 29 2005 werner@suse.de
- Avoid array overflow (bug #135587)
- Fix long standing bug: redraw shadows arounbd thumb if needed.
* Fri Jun 10 2005 meissner@suse.de
- use RPM_OPT_FLAGS.
* Wed Feb  2 2005 meissner@suse.de
- use NULL at the end of XSetIC* XGetIC* calls to remove
  warnings in gcc 4. (same way that Xaw in Xlib uses already).
* Tue Sep 21 2004 werner@suse.de
- Abort on missing fontset during initialization (bug #44037)
* Tue Sep  7 2004 werner@suse.de
- Add some check to abort if the Xt lib does not find fonts or
  fontsets (bug #44037)
* Sat Sep  4 2004 ro@suse.de
- official major version changed from 7 to 8
* Thu Aug 26 2004 werner@suse.de
- Be sure that scrollbars occurs and remain if needed
- More compatibility to Xaw
- Do not forget fontset check
* Fri Apr 30 2004 werner@suse.de
- Add patch to avoid crash within resource handling (mainly for gv)
* Mon Apr 26 2004 werner@suse.de
- Avoid compiler warnings.
* Wed Feb  4 2004 werner@suse.de
- I like labels with 3D shadow
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Tue Jul  1 2003 werner@suse.de
- Avaiod nasty `Actions not found: StartScroll' message
* Wed May 28 2003 coolo@suse.de
- use BuildRoot
* Mon May 19 2003 werner@suse.de
- Don't crash on wrong cast's: add compat patch
* Mon May  5 2003 werner@suse.de
- Update to Xaw3d-1.5E
  * Add our thumb patch
  * Add our secure patch
  * Add our hsbar patch
* Fri Apr  5 2002 pmladek@suse.cz
- used macro %%{_lib} to fix for lib64
* Thu Dec 14 2000 werner@suse.de
- Group tag
* Thu Jun 29 2000 werner@suse.de
- Add security fixes done for libXaw
- lib version 6.1 is required by older programs
* Fri May 12 2000 schwab@suse.de
- Update library version number.
- Use %%{_defaultdocdir}.
- Fix Scrollbar.c for all archs.
* Fri Mar 31 2000 nadvornik@suse.cz
- removed /usr/X11R6/include/X11 from filelist
* Fri Oct 29 1999 kukuk@suse.de
- fix Scrollbar.c for alpha
* Mon Sep 27 1999 bs@suse.de
- fixed requirements for sub packages
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Apr 27 1999 werner@suse.de
- Fix some `inner else'
* Tue Apr 27 1999 ro@suse.de
- update to 1.5
* Thu Nov 12 1998 bs@suse.de
- fixed spec file for new rpm.
* Mon May 25 1998 werner@suse.de
- Add addable security fixes of XFree86[tm] patch 3.3.2-patch2
  - Second *unused* patch to be able to reverse the background
  feature of scrollbars
* Tue May  5 1998 werner@suse.de
- Update to new release 1.4
  * add some small fixes
  - Added some changes from Dimitrios P. Bouras
  (background color for scrollbar, ...)
* Tue Oct 21 1997 werner@suse.de
- some changes for the new XFree86[tm] release
  23.08.96: (1.3)
  - Update von 1.2a Original + 1.1 Patch für scrollbar
  - 1.3 braucht kein scrollbar-3d patch mehr
    allerdings können bei 1.3 die Pfeile nicht gedrückt
    werden und die Resource scrollbarBackground arbeitet
    nicht.
